/**
 * Manages rendering of 'Clouds' pages.
 */
function Clouds() {
	
	/* Variables */
	var activeClouds = {};	// dictionary of active clouds
	var drivers = null;		// cache list of drivers
	
	/* Initializes the clouds page. */
	this.init = function() {
		console.log('Clouds.init');
		
		// To preload clouds on homepage, add line here with Basic Authentication token
		activeClouds.mock = {"name": "Mock", "auth": "Basic bW9ja3VzZXI6bW9ja3Bhc3N3b3Jk"};
		
		// Retrieve drivers
		get(dc_server + '/api/drivers?format=json', {'Accept' : 'application/json'}, null, function(resp) {
			drivers = resp;
			drivers['sbc'].name = 'IBMSmartCloud Enterprise';	// 'SBC' renamed to 'IBMSmartCloud'
		});
	};
		
	/* Renders list of active clouds to HTML string. */
	this.renderActiveClouds = function() {
		// Header
		$("#activeCloudsDivHeader").replaceWith("<div data-role='header' data-theme='b' id='activeCloudsDivHeader'/>");
		$("#activeCloudsDivHeader").append("<a style='visibility:hidden'>Temp</a>");
		$("#activeCloudsDivHeader").append("<h1>Your Clouds</h1>");
		$("#activeCloudsDivHeader").append("<a onclick='changePageSelectCloudToAdd()' data-icon='plus' class='ui-btn-right' data-iconpos='notext' data-direction='reverse'/>");
		$("#activeCloudsDivHeader").page();
		
		// Content
		$("#activeCloudsDivContent").replaceWith("<div data-role='content' id='activeCloudsDivContent'/>");
		$("#activeCloudsDivContent").append(renderActiveCloudsHTML());
		$("#activeCloudsDivContent").page();
		
		// HTML content
		function renderActiveCloudsHTML() {
			var html = "";
			var cloudsAdded = false;
//			html += "<div id='outer' style='height:100%;overflow:hidden;'>";
//			html += "<div id='inner' style='position:absolute;width:100%;'>";
			html += "<div data-role='controlgroup'>";
			for (var key in activeClouds) {
				cloudsAdded = true;
				html += "<input type='button' value='" + activeClouds[key].name + "' data-icon='arrow-r' data-iconpos='right' onclick='changePageViewCloud(\"" + key + "\")'/>";
			}
			if (!cloudsAdded) {
				html += "<i>Add a cloud to get started...</i>";
			}
			html += "</div>";
//			html += "</div>";
//			html += "</div>";
			return html;
		}
	};
	
	/* Renders list of clouds to add. */
	this.renderSelectCloudToAdd = function() {
		// Header
		$("#selectCloudToAddDivHeader").replaceWith("<div data-role='header' data-theme='b' id='selectCloudToAddDivHeader'/>");
		$("#selectCloudToAddDivHeader").append("<h1>Select Provider</h1>");
		$("#selectCloudToAddDivHeader").page();
		
		// Content
		$("#selectCloudToAddDivContent").replaceWith("<div data-role='content' id='selectCloudToAddDivContent'/>");
		if (drivers == null) {
			get(dc_server + '/api/drivers?format=json', {'Accept' : 'application/json'}, null, function(resp) {
				drivers = resp;
				drivers['sbc'].name = 'IBMSmartCloud Enterprise';
				$("#selectCloudToAddDivContent").append(renderSelectCloudToAddHTML(drivers));
				$("#selectCloudToAddDivContent").page();
			});
		} else {
			$("#selectCloudToAddDivContent").append(renderSelectCloudToAddHTML(drivers));
			$("#selectCloudToAddDivContent").page();
		}
		
		// HTML content
		function renderSelectCloudToAddHTML(drivers) {
			console.log('renderSelectCloudToAddHTML');
			var html = "";
			html += "<div data-role='controlgroup'>";
			for (var key in drivers) {
				if (activeClouds[key] == null) {
					html += "<input type='button' value='" + drivers[key].name + "' data-icon='arrow-r' data-iconpos='right' onclick='changePageAddCloud(\"" + key + "\")'/>";
				}
			}
			html += "</div>";
			return html;
		}
	};
	
	/* Renders page to add a cloud. */
	this.renderAddCloud = function(cloudId) {
		// Header
		$("#addCloudDivHeader").replaceWith("<div data-role='header' data-theme='b' id='addCloudDivHeader'/>");
		$("#addCloudDivHeader").append("<h1>Account Setup</h1>");
		$("#addCloudDivHeader").page();
		
		// Content
		$("#addCloudDivContent").replaceWith("<div data-role='content' id='addCloudDivContent'/>");
		$("#addCloudDivContent").append(renderAddCloudHTML(this.lookupDriver(cloudId).name));
		$("#addCloudDivContent").page();
		
		// HTML content
		function renderAddCloudHTML(cloudName) {
			var html = "";
			html += "<table width='100%'>";
			html += "<tr><td colspan='2'><b>Enter credentials for " +cloudName + "</b></td></tr>";
			html += "<tr><td width='10%'>Username:</td><td align='right' width='90%'><input type='text' id='username'/></td></tr>";
			html += "<tr><td width='10%'>Password:</td><td align='right' width='90%'><input type='password' id='password'/></td></tr>";
			html += "</table>";
			html += "<input type='button' value='Submit' onclick='verifyCredentials(\"" + cloudId + "\")'/>";
			return html;
		}
	};
	
	/* Renders page to add a cloud. */
	this.renderViewCloud = function(cloudId) {
		console.log("Clouds.renderViewCloud(" + cloudId + ")");
		console.log("cloudId: " + cloudId);
		var name = this.lookupDriver(cloudId).name;
		
		// Header
		$("#viewCloudDivHeader").replaceWith("<div data-role='header' data-theme='b' id='viewCloudDivHeader'/>");
		$("#viewCloudDivHeader").append("<h1>Manage " + name + "</h1>");
		$("#viewCloudDivHeader").page();
		
		// Content
		$("#viewCloudDivContent").replaceWith("<div data-role='content' id='viewCloudDivContent'/>");
		$("#viewCloudDivContent").append(renderViewCloudHTML());
		$("#viewCloudDivContent").page();
		
		// HTML content
		function renderViewCloudHTML() {
			var html = "";
			html += "<div data-role='controlgroup'>";
			html += "<a data-role='button' onclick='changePageInstances([\"" + cloudId + "\"], false)' data-icon='arrow-r' data-iconpos='right'>Instances</a>";
			html += "<a data-role='button' onclick='changePageImages([\"" + cloudId + "\"])' data-icon='arrow-r' data-iconpos='right'>Images</a>";
			html += "<a data-role='button' onclick='changePageRealms(\"" + cloudId + "\")' data-icon='arrow-r' data-iconpos='right'>Realms</a>";
			html += "<a data-role='button' onclick='changePageHardwareProfiles(\"" + cloudId + "\")' data-icon='arrow-r' data-iconpos='right'>Hardware Profiles</a>";
			html += "</div>";
			html += "<a data-role='button' data-theme='b' onclick='deleteActiveCloud(\"" + cloudId + "\")'>Remove Account</a>";
			return html;
		}
	};
	
	/* Renders page to view a cloud's realms. */
	this.renderViewRealms = function(cloudId) {
		console.log('Clouds.renderViewRealms(' + cloudId + ')');
		
		var cloud = this.lookupActiveCloud(cloudId);
		var name = cloud.name;
		var auth = cloud.auth;
		
		// Header
		$("#viewRealmsDivHeader").replaceWith("<div data-role='header' data-theme='b' id='viewRealmsDivHeader'/>");
		$("#viewRealmsDivHeader").append("<h1>Realms</h1>");
		$("#viewRealmsDivHeader").page();
		
		// Content
		$("#viewRealmsDivContent").replaceWith("<div data-role='content' id='viewRealmsDivContent'/>");
		var headers = {
			'Accept' : 'application/json',
			'Authorization': auth,
			'X-Deltacloud-Driver': cloudId
		};
		get(dc_server + '/api/realms?format=json', headers, null, function(resp) {
			var realms = resp.realms;
			$("#viewRealmsDivContent").append(renderViewRealmsHTML(realms));
			$("#viewRealmsDivContent").page();
		});
		
		// HTML content
		function renderViewRealmsHTML(realms) {
			var html = "";
			html += "<table border='1' width='100%'>";
			html += "<tr bgcolor='#999999'>";
			html += "<td width='40%'><b>ID</b></td>";
			html += "<td><b>Name</b</td>";
			html += "<td><b>State</b</td>";
			html += "<td><b>Limit</b</td>";
			html += "</tr>";
			for (i = 0; i < realms.length; i++) {
				html += "<tr>"
				html += "<td bgcolor='#CCCCCC'>" + realms[i].id + "</td>";
				html += "<td bgcolor='#CCCCCC'>" + realms[i].name + "</td>";
				html += "<td bgcolor='#CCCCCC'>" + realms[i].state + "</td>";
				html += "<td bgcolor='#CCCCCC'>" + realms[i].limit + "</td>";
				html += "</tr>";
			}
			html += "</table>";
			return html;
		}
	};
	
	/* Renders page to view a cloud's hardware profiles. */
	this.renderViewHardwareProfiles = function(cloudId) {
		console.log('Clouds.renderViewHardwareProfiles(' + cloudId + ')');
		
		var cloud = this.lookupDriver(cloudId);
		var name = cloud.name;
		var auth = cloud.auth;
		console.log(auth);
		
		// Header
		$("#viewHardwareProfilesDivHeader").replaceWith("<div data-role='header' data-theme='b' id='viewHardwareProfilesDivHeader'/>");
		$("#viewHardwareProfilesDivHeader").append("<h1>Hardware Profiles</h1>");
		$("#viewHardwareProfilesDivHeader").page();
		
		// Content
		$("#viewHardwareProfilesDivContent").replaceWith("<div data-role='content' id='viewHardwareProfilesDivContent'/>");
		var headers = {
			'Accept' : 'application/json',
			'Authorization': auth,
			'X-Deltacloud-Driver': cloudId
		};
		get(dc_server + '/api/hardware_profiles?format=json', headers, null, function(resp) {
			var hwps = resp.hardware_profiles;
			$("#viewHardwareProfilesDivContent").append(renderViewHardwareProfilesHTML(hwps));
			$("#viewHardwareProfilesDivContent").page();
		});
		
		// HTML content
		function renderViewHardwareProfilesHTML(hwps) {
			var html = "";
			html += "<table border='1' width='100%'>";
			html += "<tr bgcolor='#999999'>";
			html += "<td width='50%' ><b>Name</b></td>";
			html += "<td><b>Architecture</b></td>";
			html += "<td><b>Memory</b</td>";
			html += "<td><b>Storage</b</td>";
			html += "<td><b>CPUs</b</td>";
			html += "</tr>";
			for (i = 0; i < hwps.length; i++) {
				if (hwps[i].properties.length == 4) {
					html += "<tr>"
					html += "<td bgcolor='#CCCCCC'>" + hwps[i].id + "</td>";
					html += "<td bgcolor='#CCCCCC'>" + hwps[i].properties[1].value + "</td>";
					html += "<td bgcolor='#CCCCCC'>" + hwps[i].properties[0].value + "</td>";
					html += "<td bgcolor='#CCCCCC'>" + hwps[i].properties[2].value + "</td>";
					html += "<td bgcolor='#CCCCCC'>" + hwps[i].properties[3].value + "</td>";
					html += "</tr>";
				}
			}
			html += "</table>";
			return html;
		}
	};
	
	/* Adds a cloud to the list of active clouds. */
	this.addActiveCloud = function(cloudId, authToken) {
		var driver = this.lookupDriver(cloudId);
		activeClouds[cloudId] = {"name": this.lookupDriver(cloudId).name, "auth": authToken};
	};
	
	/* Looks up a driver based on cloud ID. */
	this.lookupDriver = function(cloudId) {
		console.log('lookupDriver(' + cloudId + ')');
		for (var key in drivers) {
			if (key == cloudId) {
				return drivers[key]; 
			}
		}
		console.log("***Cloud ID: " + cloudId + " not found***");
		return null;
	};
	
	/* Looks up an active cloud based on cloud ID. */
	this.lookupActiveCloud = function(cloudId) {
		console.log('lookupActiveCloud(' + cloudId + ')');
		for (var key in activeClouds) {
			if (key == cloudId) {
				return activeClouds[key]; 
			}
		}
		console.log("***Cloud ID: " + cloudId + " not found***");
		return null;
	};
	
	/* Returns list of active clouds. */
	this.getActiveClouds = function() {
		return activeClouds;
	};
	
	/* Returns ids of active clouds. */
	this.getActiveCloudIds = function() {
		var ids = [];
		var idx = 0;
		for (var key in activeClouds) {
			ids[idx] = key;
			idx++;
		}
		return ids;
	};
	
	/* Removes an account from the list of active accounts. */
	this.removeActiveCloud = function(cloudId) {
		delete activeClouds[cloudId];
	};
}