/**
 * Manages the images page.
 */
function Images() {
	
	/* Variables */
	var filteredClouds = [];	// List of clouds to show images for
	
	/* Initializes the images management js */
	this.init = function() {
		
	};
	
	/* Renders the page to view images. */
	this.renderViewImages = function(instant) {
		console.log('Images.renderViewImages()');
		
		// Header
		$("#viewImagesDivHeader").replaceWith("<div data-role='header' data-position='fixed' data-theme='b' id='viewImagesDivHeader'/>");
		if (instant) $("#viewImagesDivHeader").append("<a style='visibility:hidden'>Temp</a>");
		$("#viewImagesDivHeader").append("<h1>Available Images</h1>");
		$("#viewImagesDivHeader").page();
		
		// Content
		$("#viewImagesDivContent").replaceWith("<div data-role='content' id='viewImagesDivContent'/>");
		renderViewImagesHTML(this.filteredClouds);
		
		/* Renders HTML for images page. */
		function renderViewImagesHTML(filteredClouds) {
			for (i = 0; i < filteredClouds.length; i++) {
				handleCloud(filteredClouds[i]);
			}
			
			/* Retrieves the images for a cloud, generates HTML, and calls the monitor. */
			function handleCloud(cloudId) {
				
				var cloud = cloudManager.lookupActiveCloud(cloudId);
				var name = cloud.name;
				var auth = cloud.auth;
				
				var headers = {
					'Accept' : 'application/json',
					'Authorization': auth,
					'X-Deltacloud-Driver': cloudId
				};
				get(dc_server + '/api/images?format=json', headers, null, function(resp) {
					var images = resp.images;
					var html = "";
					console.log('constructing HTML');
					console.log(cloudId);
//					html += "<h1 id='hd1' style='position:absolute;width:100%;z-index:1;'></h1>";
//					html += "<div id='outer' style='height:100%;overflow:hidden;'>";
//					html += "<div id='inner' style='position:absolute;width:100%;'>";
					if (filteredClouds.length == 1) {
						html += "<div data-role='content'>";
					} else {
						html += "<div data-role='collapsible' data-collapsed='true' data-theme='a'>";
						html += "<h1>" + cloudManager.lookupDriver(cloudId).name + "</h1>";
					}
					html += "<ul data-role='listview' data-inset='true' data-theme='c' data-dividertheme='a'>";
					if (filteredClouds.length == 1)
						html += "<li data-role='list-divider'>" + cloudManager.lookupDriver(cloudId).name + "</li>";
					for (j = 0; j < images.length; j++) {
						html += "<li><a onclick='changePageViewImage(\"" + cloudId + "\", " + JSON.stringify(images[j]) + ")' data-icon='arrow-r' data-iconpos='right'>" + images[j].name + "</a></li>";
					}
					html += "</ul></div>";
//					html += "</div>";
//					html += "</div>";
					console.log("calling callback monitor");
					callbackMonitor(html, filteredClouds);
				});
			}
			
			/* Monitors retrieval of images; renders when all clouds done. */
			var count = 0;
			var allHTML = "";
			function callbackMonitor(html, filteredClouds) {
				count++;
				allHTML += html;
				if (count == filteredClouds.length) {
					console.log("done gathering images, paging");
					$("#viewImagesDivContent").append(allHTML);
					$("#viewImagesDivContent").page();
				}
			}
		}
	};
	
	/* Renders the page to view an image. */
	this.renderViewImage = function(cloud, image) {
		console.log('Images.renderViewImage');
		
		// Header
		$("#viewImageDivHeader").replaceWith("<div data-role='header' data-theme='b' id='viewImageDivHeader'/>");
		$("#viewImageDivHeader").append("<h1>Image</h1>");
		$("#viewImageDivHeader").page();
		
		// Content
		$("#viewImageDivContent").replaceWith("<div data-role='content' id='viewImageDivContent'/>");
		$("#viewImageDivContent").append(renderViewImageHTML(image));
		$("#viewImageDivContent").page();
		
		/* Renders HTML to view an image. */
		function renderViewImageHTML(image) {
			var html = "";
			html += "<p><h1>" + image.name + "</h1></p>";
			html += "<p>" + image.description + "</p>";
			html += "<table width='100%' cellspacing='0' cellpadding='8'>";
			html += "<tr><td bgcolor=#999999><b>ID</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + image.id + "</td></tr>";
			html += "<tr><td bgcolor=#999999><b>Architecture</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + image.architecture + "</td></tr>";
			html += "<tr><td bgcolor=#999999><b>URL</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + image.href + "</td></tr>";
			html += "<tr><td bgcolor=#999999><b>Owner ID</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + image.owner_id + "</td></tr>";
			html += "<tr><td bgcolor=#999999><b>State ID</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + image.state + "</td></tr>";
			html += "</table>";
			html += "<input type='button' value='Provision' onclick='provisionImage(\"" + image.id + "\")'/>";
			return html;
		}
	};
	
	/* Sets the list of clouds to show images for. */
	this.setFilteredClouds = function(cloudIds) {
		console.log('Images.setFilteredClouds');
		this.filteredClouds = cloudIds;
	};
	
	/* Gets the list of clouds to show images for. */
	this.getFilteredClouds = function() {
		return this.filteredClouds;
	};
}