/**
 * Manages the instances page.
 */
function Instances() {
	
	/* Variables */
	var filteredClouds = []; // List of clouds to show instances for
	
	/* Initializes the images management js */
	this.init = function() {
		
	};
	
	/* Renders the page to view instances. */
	this.renderViewInstances = function(instant) {
		console.log('Instances.renderViewInstances()');
		
		// Header
		$("#viewInstancesDivHeader").replaceWith("<div data-role='header' data-theme='b' id='viewInstancesDivHeader'/>");
		if (instant) $("#viewInstancesDivHeader").append("<a style='visibility:hidden'>Temp</a>");
		$("#viewInstancesDivHeader").append("<h1>Instances</h1>");
		$("#viewInstancesDivHeader").page();
		
		// Content
		$("#viewInstancesDivContent").replaceWith("<div data-role='content' id='viewInstancesDivContent'/>");
		renderViewInstancesHTML(this.filteredClouds);
		
		//$("#footerDivId").page();
		
		/* Renders HTML for images page. */
		function renderViewInstancesHTML(filteredClouds) {
			for (i = 0; i < filteredClouds.length; i++) {
				handleCloud(filteredClouds[i]);
			}
			
			/* Retrieves the instances for a cloud, generates HTML, and calls the monitor. */
			function handleCloud(cloudId) {
				var cloud = cloudManager.lookupActiveCloud(cloudId);
				var name = cloud.name;
				var auth = cloud.auth;
				
				var headers = {
					'Accept' : 'application/json',
					'Authorization': auth,
					'X-Deltacloud-Driver': cloudId
				};
				get(dc_server + '/api/instances?format=json', headers, null, function(resp) {
					var instances = resp.instances;
					var html = "";
					console.log('constructing HTML');
					console.log(cloudId);
					
					console.log(filteredClouds.length);
					
					if (filteredClouds.length == 1) {
						html += "<div data-role='content'>";
					} else {
						html += "<div data-role='collapsible' data-theme='a'>";
						html += "<h1>" + cloudManager.lookupDriver(cloudId).name + "</h1>";
					}
					html += "<ul data-role='listview' data-inset='true' data-theme='c' data-dividertheme='a'>";
					if (filteredClouds.length == 1)
						html += "<li data-role='list-divider'>" + cloudManager.lookupDriver(cloudId).name + "</li>";
					for (j = 0; j < instances.length; j++) {
						var picName = "";
						if (instances[j].state == 'RUNNING') {
							picName = "green.png";
						} else if (instances[j].state == "PENDING") {
							picName = "yellow.png";
						} else {
							picName = "red.png";
						}
						html += "<li><a onclick='changePageViewInstance(\"" + cloudId + "\", \"" + escape(JSON.stringify(instances[j])) + "\")' data-icon='arrow-r' data-iconpos='right'>" + instances[j].name + "<img src='images/" + picName + "'/></a></li>";
					}
					html += "</ul></div>";
					console.log("calling callback monitor");
					callbackMonitor(html, filteredClouds);
				});
			}
			
			/* Monitors retrieval of images; renders when all clouds done. */
			var count = 0;
			var allHTML = "";
			function callbackMonitor(html, filteredClouds) {
				count++;
				allHTML += html;
				if (count == filteredClouds.length) {
					console.log("paging div");
					$("#viewInstancesDivContent").append(allHTML);
					$("#viewInstancesDivContent").page();
				}
			}
		}
	};
	
	/* Renders the page to view an instance. */
	this.renderViewInstance = function(cloudId, instance) {
		console.log('Instances.renderViewInstance');
		
		// Header
		$("#viewInstanceDivHeader").replaceWith("<div data-role='header' data-theme='b' id='viewInstanceDivHeader'/>");
		$("#viewInstanceDivHeader").append("<h1>Instance</h1>");
		$("#viewInstanceDivHeader").page();
		
		// Content
		$("#viewInstanceDivContent").replaceWith("<div data-role='content' id='viewInstanceDivContent'/>");
		$("#viewInstanceDivContent").append(renderViewInstanceHTML(instance));
		$("#viewInstanceDivContent").page();
		
		/* Renders HTML to view an image. */
		function renderViewInstanceHTML(instance) {
			var html = "";
			var publicIps = "";
			for (i = 0; i < instance.public_addresses.length; i++) {
				publicIps += instance.public_addresses[i] + " ";
			}
			
			var picName = "";
			if (instance.state == 'RUNNING') {
				picName = "green.png";
			} else if (instance.state == "PENDING") {
				picName = "yellow.png";
			} else {
				picName = "red.png";
			}
			
			html += "<table>";
			html += "<tr>";
			html += "<td width='100%'><h1>" + instance.name + "</h1></td>";
			html += "<td><img src='images/" + picName + "' height='75px' width='75px'/></td>";
			html += "</tr>";
			html += "</table>";
			html += "<table width='100%' cellspacing='0' cellpadding='8'>";
			html += "<tr><td bgcolor=#999999><b>ID</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + instance.id + "</td></tr>";
			html += "<tr><td bgcolor=#999999><b>State</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + instance.state + "</td></tr>";
			html += "<tr><td bgcolor=#999999><b>Image ID</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + instance.image_id + "</td></tr>";
			html += "<tr><td bgcolor=#999999><b>Public IP(s)</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + publicIps + "</td></tr>";
			html += "<tr><td bgcolor=#999999><b>Realm ID</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + instance.realm_id + "</td></tr>";
			html += "<tr><td bgcolor=#999999><b>URL</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + instance.href + "</td></tr>";
			html += "<tr><td bgcolor=#999999><b>Owner ID</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + instance.owner_id + "</td></tr>";
			html += "<tr><td bgcolor=#999999><b>Launch Time</b></td></tr>";
			html += "<tr><td bgcolor=#CCCCCC style='text-indent:10px;'>" + instance.launch_time + "</td></tr>";
			html += "</table>";
			for (i = 0; i < instance.actions.length; i++) {
				html += "<input type='button' value='" + instance.actions[i] + "' onclick='instanceAction(\"" + cloudId + "\", \"" + instance.id + "\", \"" + instance.actions[i] + "\")'/>";
			}
			return html;
		}
	};
	
	/* Sets the list of clouds to show instances for. */
	this.setFilteredClouds = function(clouds) {
		this.filteredClouds = clouds;
	};
	
	/* Gets the list of clouds to show instances for. */
	this.getFilteredClouds = function() {
		return this.filteredClouds;
	};
}